@@ -16,7 +16,7 @@ import logging
 
 logger = logging.getLogger('giza.config.git')
 
-from giza.git import GitRepo
+from giza.core.git import GitRepo
 from giza.config.base import ConfigurationBase
 
 class GitConfigBase(ConfigurationBase):
@@ -128,18 +128,4 @@ class GitBranchConfig(GitConfigBase):
             self.state['published'] = 'master'
 
 class GitRemoteConfig(ConfigurationBase):
-    @property
-    def upstream(self):
-        return self.state['upstream']
-
-    @upstream.setter
-    def upstream(self, value):
-        self.state['upstream'] = value
-
-    @property
-    def tools(self):
-        return self.state['tools']
-
-    @tools.setter
-    def tools(self, value):
-        self.state['tools'] = value
+    _option_registry = ['upstream', 'tools']
